colcon-ed
=========

An extension for `colcon-core <https://github.com/colcon/colcon-core>`_ to edit a file within a package.

See the `documentation <https://colcon.readthedocs.io/en/released/reference/verb/edit.html>`_ on how to use it.
